==> agr-center-api-3.0.0-CLOUD-UAT-20221109.015322-15-sources.jar: com/tydic/dyc/agr/service/domainservice/bo/AgrItemAdjustChngBo.java <==
package com.tydic.dyc.agr.service.domainservice.bo;

import lombok.Data;
import java.io.Serializable;
import com.tydic.dyc.agr.service.agr.bo.AgrItemLadderPriceBo;
import com.tydic.dyc.agr.service.agr.bo.AgrItemExtBo;
import java.math.BigDecimal;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2022-10-24 16:03
 **/
@Data
public class AgrItemAdjustChngBo implements Serializable {
	private static final long serialVersionUID =  -6804353303262988479L;

	/**
	 * 明细变更类型
	 */
	private Integer itemChngType;
	/**
	 * 协议明细状态
	 */
	private Integer agrSkuStatus;
	/**
	 * 物料ID
	 */
	private String materialId;
	/**
	 * 物料编码
	 */
	private String materialCode;
	/**
	 * 物料名称
	 */
	private String materialName;
	/**
	 * 型号
	 */
	private String model;
	/**
	 * 图号
	 */
	private String figure;
	/**
	 * 规格
	 */
	private String spec;
	/**
	 * 材质
	 */
	private String texture;
	/**
	 * 品牌ID
	 */
	private Long brandId;
	/**
	 * 品牌
	 */
	private String brandName;
	/**
	 * 是否成品油
	 */
	private Integer whetherOil;
	/**
	 * 生产厂家
	 */
	private String manufacturer;
	/**
	 * 计量单位ID
	 */
	private Long measureId;
	/**
	 * 计量单位
	 */
	private String measureName;
	/**
	 * 数量
	 */
	private BigDecimal buyNumber;
	/**
	 * 最小起订量
	 */
	private BigDecimal moq;
	/**
	 * 采购单价
	 */
	private BigDecimal buyPrice;
	/**
	 * 采购总价
	 */
	private BigDecimal buyPriceSum;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 销售单价
	 */
	private BigDecimal salePrice;
	/**
	 * 销售总价
	 */
	private BigDecimal salePriceSum;
	/**
	 * 折扣率
	 */
	private BigDecimal discountRate;
	/**
	 * 原折扣率
	 */
	private BigDecimal oldDiscountRate;
	/**
	 * 市场价
	 */
	private BigDecimal marketPrice;
	/**
	 * 协议价
	 */
	private BigDecimal agrPrice;
	/**
	 * 阶梯价组ID
	 */
	private Long ladderPriceId;
	/**
	 * 管理单位ID
	 */
	private Long managementOrgId;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 分类ID
	 */
	private String catalogId;
	/**
	 * 分类编码
	 */
	private String catalogCode;
	/**
	 * 分类名称
	 */
	private String catalogName;
	/**
	 * 税收分类编码
	 */
	private String taxCatalog;
	/**
	 * 质保等级
	 */
	private String warrantyLevel;
	/**
	 * 税率
	 */
	private BigDecimal taxRate;
	/**
	 * 商品铺货标识
	 */
	private Integer skuSymbol;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议明细变更ID
	 */
	private Long agrItemChngId;
	/**
	 * 协议明细ID
	 */
	private Long agrItemId;
	/**
	 * 协议明细阶梯价
	 */
	private List<AgrItemLadderPriceBo> agrItemLadderPriceChng;
	/**
	 * 协议明细扩展
	 */
	private List<AgrItemExtBo> agrItemExtChng;
	/**
	 * 明细变更类型转义
	 */
	private String itemChngTypeStr;
	/**
	 * 是否成品油转义
	 */
	private String whetherOilStr;
	/**
	 * 商品类型ID
	 */
	private Long commodityTypeId;
	/**
	 * 商品类型名称
	 */
	private String commodityTypeName;
	/**
	 * 调整后数量
	 */
	private BigDecimal newbuyNumber;
	/**
	 * 调整后采购单价
	 */
	private BigDecimal newbuyPrice;
	/**
	 * 调整后采购总价
	 */
	private BigDecimal newbuyPriceSum;
	/**
	 * 调整后加价比率（%）
	 */
	private BigDecimal newmarkupRate;
	/**
	 * 调整后销售单价
	 */
	private BigDecimal newsalePrice;
	/**
	 * 调整后销售总价
	 */
	private BigDecimal newsalePriceSum;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> agr-center-api-3.2.0-CLOUD-UAT-20240131.114200-5-sources.jar: com/tydic/dyc/agr/service/domainservice/bo/AgrItemAdjustChngBo.java <==
package com.tydic.dyc.agr.service.domainservice.bo;

import lombok.Data;
import java.io.Serializable;
import com.tydic.dyc.agr.service.agr.bo.AgrItemLadderPriceBo;
import com.tydic.dyc.agr.service.agr.bo.AgrItemExtBo;
import java.math.BigDecimal;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-02-08 12:03
 **/
@Data
public class AgrItemAdjustChngBo implements Serializable {
	private static final long serialVersionUID =  8931341439497840082L;

	/**
	 * 明细变更类型
	 */
	private Integer itemChngType;
	/**
	 * 协议明细状态
	 */
	private Integer agrSkuStatus;
	/**
	 * 物料ID
	 */
	private String materialId;
	/**
	 * 物料编码
	 */
	private String materialCode;
	/**
	 * 物料名称
	 */
	private String materialName;
	/**
	 * 型号
	 */
	private String model;
	/**
	 * 图号
	 */
	private String figure;
	/**
	 * 规格
	 */
	private String spec;
	/**
	 * 材质
	 */
	private String texture;
	/**
	 * 品牌ID
	 */
	private Long brandId;
	/**
	 * 品牌
	 */
	private String brandName;
	/**
	 * 是否成品油
	 */
	private Integer whetherOil;
	/**
	 * 生产厂家
	 */
	private String manufacturer;
	/**
	 * 计量单位ID
	 */
	private Long measureId;
	/**
	 * 计量单位
	 */
	private String measureName;
	/**
	 * 数量
	 */
	private BigDecimal buyNumber;
	/**
	 * 最小起订量
	 */
	private BigDecimal moq;
	/**
	 * 采购单价
	 */
	private BigDecimal buyPrice;
	/**
	 * 采购总价
	 */
	private BigDecimal buyPriceSum;
	/**
	 * 加价比率（%）
	 */
	private BigDecimal markupRate;
	/**
	 * 销售单价
	 */
	private BigDecimal salePrice;
	/**
	 * 销售总价
	 */
	private BigDecimal salePriceSum;
	/**
	 * 折扣率
	 */
	private BigDecimal discountRate;
	/**
	 * 原折扣率
	 */
	private BigDecimal oldDiscountRate;
	/**
	 * 市场价
	 */
	private BigDecimal marketPrice;
	/**
	 * 协议价
	 */
	private BigDecimal agrPrice;
	/**
	 * 阶梯价组ID
	 */
	private Long ladderPriceId;
	/**
	 * 管理单位ID
	 */
	private String managementOrgId;
	/**
	 * 供货商ID
	 */
	private Long supplierId;
	/**
	 * 供货商名称
	 */
	private String supplierName;
	/**
	 * 供货周期
	 */
	private Integer supplyCycle;
	/**
	 * 分类ID
	 */
	private String catalogId;
	/**
	 * 分类编码
	 */
	private String catalogCode;
	/**
	 * 分类名称
	 */
	private String catalogName;
	/**
	 * 税收分类编码
	 */
	private String taxCatalog;
	/**
	 * 质保等级
	 */
	private String warrantyLevel;
	/**
	 * 税率
	 */
	private BigDecimal taxRate;
	/**
	 * 商品铺货标识
	 */
	private Integer skuSymbol;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 协议明细变更ID
	 */
	private Long agrItemChngId;
	/**
	 * 协议明细ID
	 */
	private Long agrItemId;
	/**
	 * 协议明细阶梯价
	 */
	private List<AgrItemLadderPriceBo> agrItemLadderPriceChng;
	/**
	 * 协议明细扩展
	 */
	private List<AgrItemExtBo> agrItemExtChng;
	/**
	 * 明细变更类型转义
	 */
	private String itemChngTypeStr;
	/**
	 * 是否成品油转义
	 */
	private String whetherOilStr;
	/**
	 * 商品类型ID
	 */
	private Long commodityTypeId;
	/**
	 * 商品类型名称
	 */
	private String commodityTypeName;
	/**
	 * 调整后数量
	 */
	private BigDecimal newbuyNumber;
	/**
	 * 调整后采购单价
	 */
	private BigDecimal newbuyPrice;
	/**
	 * 调整后采购总价
	 */
	private BigDecimal newbuyPriceSum;
	/**
	 * 调整后加价比率（%）
	 */
	private BigDecimal newmarkupRate;
	/**
	 * 调整后销售单价
	 */
	private BigDecimal newsalePrice;
	/**
	 * 调整后销售总价
	 */
	private BigDecimal newsalePriceSum;
	/**
	 * 排序
	 */
	private String orderBy;

}
